@@ -36,6 +36,7 @@
 #include "MenuItem.hh"
 #include "MenuSeparator.hh"
 #include "ImageControl.hh"
+#include "MemFun.hh"
 #include "MenuTheme.hh"
 #include "App.hh"
 #include "EventManager.hh"
@@ -67,7 +68,7 @@
 
 #ifdef DEBUG
 #include <iostream>
-using std::cout;
+using std::cerr;
 using std::endl;
 #endif // DEBUG
 
@@ -121,7 +122,7 @@ Menu::Menu(FbTk::ThemeProxy<MenuTheme> &tm, ImageControl &imgctrl):
     m_hide_timer.fireOnce(true);
 
     // make sure we get updated when the theme is reloaded
-    tm.reconfigSig().attach(this);
+    m_tracker.join(tm.reconfigSig(), MemFun(*this, &Menu::themeReconfigured));
 
     m_title_vis = true;
 
@@ -254,9 +255,10 @@ void Menu::fixMenuItemIndices() {
 int Menu::remove(unsigned int index) {
     if (index >= menuitems.size()) {
 #ifdef DEBUG
-        cout << "Bad index (" << index << ") given to Menu::remove()"
-                  << " -- should be between 0 and " << menuitems.size()-1
-                  << " inclusive." << endl;
+        cerr << __FILE__ << "(" << __LINE__ << ") Bad index (" << index
+             << ") given to Menu::remove()"
+             << " -- should be between 0 and " << menuitems.size()-1
+             << " inclusive." << endl;
 #endif // DEBUG
         return -1;
     }
@@ -705,7 +707,8 @@ void Menu::drawSubmenu(unsigned int index) {
         // ensure we do not divide by 0 and thus cause a SIGFPE
         if (m_rows_per_column == 0) {
 #if DEBUG
-            cout << "Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
+            cerr << __FILE__ << "(" << __LINE__
+                 << ") Error: m_rows_per_column == 0 in FbTk::Menu::drawSubmenu()\n";
 #endif
             return;
         }
@@ -780,7 +783,8 @@ int Menu::drawItem(FbDrawable &drawable, unsigned int index,
     // ensure we do not divide by 0 and thus cause a SIGFPE
     if (m_rows_per_column == 0) {
 #if DEBUG
-        cout << "Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
+        cerr << __FILE__ << "(" << __LINE__
+             << ") Error: m_rows_per_column == 0 in FbTk::Menu::drawItem()\n";
 #endif
         return 0;
     }
@@ -1229,7 +1233,7 @@ void Menu::stopHide() {
     m_hide_timer.stop();
 }
 
-void Menu::update(FbTk::Subject *subj) {
+void Menu::themeReconfigured() {
 
     m_need_update = true;
 
@@ -1241,7 +1245,6 @@ void Menu::update(FbTk::Subject *subj) {
     reconfigure();
 }
 
-
 void Menu::setScreen(int x, int y, int w, int h) {
     m_screen_x = x;
     m_screen_y = y;
@@ -1269,7 +1272,8 @@ void Menu::clearItem(int index, bool clear, int search_index) {
     // ensure we do not divide by 0 and thus cause a SIGFPE
     if (m_rows_per_column == 0) {
 #if DEBUG
-        cout << "Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
+        cerr << __FILE__ << "(" << __LINE__
+             << ") Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
 #endif
         return;
     }
@@ -1313,7 +1317,8 @@ void Menu::highlightItem(int index) {
     // ensure we do not divide by 0 and thus cause a SIGFPE
     if (m_rows_per_column == 0) {
 #if DEBUG
-        cout << "Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
+        cerr << __FILE__ << "(" << __LINE__
+             << ") Error: m_rows_per_column == 0 in FbTk::Menu::highlightItem()\n";
 #endif
         return;
     }
@@ -1378,7 +1383,8 @@ void Menu::drawLine(int index, int size){
     // ensure we do not divide by 0 and thus cause a SIGFPE
     if (m_rows_per_column == 0) {
 #if DEBUG
-        cout << "Error: m_rows_per_column == 0 in FbTk::Menu::clearItem()\n";
+        cerr << __FILE__ << "(" << __LINE__
+             << ") Error: m_rows_per_column == 0 in FbTk::Menu::drawLine()\n";
 #endif
         return;
     }
