@@ -90,7 +90,7 @@ void WindowListCmd::execute() {
                 WindowCmd<void>::setWindow((*it)->fbwindow());
             else if (typeid(**it) == typeid(WinClient))
                 WindowCmd<void>::setClient(dynamic_cast<WinClient *>(*it));
-            if (!*m_filter || m_filter->execute())
+            if (!m_filter || m_filter->execute())
                 m_cmd->execute();
         }
         WindowCmd<void>::setClient(old);
@@ -509,7 +509,7 @@ void ShowDesktopCmd::execute() {
     for (; it != it_end; ++it) {
         if (!(*it)->fbwindow()->isIconic() && ((*it)->fbwindow()->isStuck() ||
             (*it)->fbwindow()->workspaceNumber() == space) &&
-            (*it)->fbwindow()->layerNum() < Layer::DESKTOP) {
+            (*it)->fbwindow()->layerNum() < ResourceLayer::DESKTOP) {
             (*it)->fbwindow()->iconify();
             count++;
         }
