@@ -52,6 +52,10 @@
   #include <string.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+  #include <unistd.h>
+#endif
+
 #ifdef HAVE_SYS_STAT_H
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -152,11 +156,6 @@ static void showInfo(ostream &ostr) {
 #endif // USE_NEWWMSPEC
         "EWMH" << endl <<
 
-#ifndef USE_GNOME
-        NOT <<
-#endif // USE_GNOME
-        "GNOME" << endl <<
-
 #ifndef HAVE_IMLIB2
         NOT<<
 #endif // HAVE_IMLIB2
@@ -365,13 +364,19 @@ void setupConfigFiles(const std::string& dirname, const std::string& rc) {
         }
     }
 
+    bool sync_fs = false;
+
     // copy default files if needed
     for (size_t i = 0; i < nr_of_cfiles; ++i) {
         if (cfiles[i].create_file) {
             FbTk::FileUtil::copyFile(cfiles[i].default_name, cfiles[i].filename.c_str());
+            sync_fs = true;
         }
     }
 
+    if (sync_fs) {
+       sync();
+    }
 }
 
 
@@ -408,6 +413,7 @@ void updateConfigFilesIfNeeded(const std::string& rc_file) {
                 << commandargs
                 << "' failed." << endl;
         }
+        sync();
     }
 }
 
